@@ -2,13 +2,12 @@
 
 import logging
 
-from aop2db.orm.models import Base
-from aop2db.utils import get_conn
-
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 from sqlalchemy_utils import create_database, database_exists
 
+from aop2db.orm.models import Base
+from aop2db.utils import get_conn
 
 logger = logging.getLogger(__name__)
 
@@ -17,7 +16,7 @@ CONN = get_conn()
 if not database_exists(CONN):
     create_database(CONN)
 
-engine = create_engine(CONN, convert_unicode=True)
+engine = create_engine(CONN)
 session = sessionmaker(bind=engine)
 
 
