@@ -1,6 +1,6 @@
 """Model definitions."""
 
-from sqlalchemy import Column, DateTime, ForeignKey, Integer, String, TEXT, Table
+from sqlalchemy import TEXT, Column, DateTime, ForeignKey, Integer, String, Table
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import relationship
 
@@ -8,24 +8,24 @@ Base = declarative_base()
 
 # AOP
 stressor_chemical = Table(
-    'stressor_chemical_association',
+    "stressor_chemical_association",
     Base.metadata,
-    Column('stressor_id', ForeignKey('aop_stressor.id'), primary_key=True),
-    Column('chemical_id', ForeignKey('aop_chemical.id'), primary_key=True),
+    Column("stressor_id", ForeignKey("aop_stressor.id"), primary_key=True),
+    Column("chemical_id", ForeignKey("aop_chemical.id"), primary_key=True),
 )
 
 ke_be = Table(
-    'key_event_bio_event_association',
+    "key_event_bio_event_association",
     Base.metadata,
-    Column('key_event_id', ForeignKey('aop_key_event.id'), primary_key=True),
-    Column('bio_event_id', ForeignKey('aop_bio_event.id'), primary_key=True),
+    Column("key_event_id", ForeignKey("aop_key_event.id"), primary_key=True),
+    Column("bio_event_id", ForeignKey("aop_bio_event.id"), primary_key=True),
 )
 
 stressor_ke = Table(
-    'stressor_key_event_association',
+    "stressor_key_event_association",
     Base.metadata,
-    Column('key_event_id', ForeignKey('aop_key_event.id'), primary_key=True),
-    Column('stressor_id', ForeignKey('aop_stressor.id'), primary_key=True),
+    Column("key_event_id", ForeignKey("aop_key_event.id"), primary_key=True),
+    Column("stressor_id", ForeignKey("aop_stressor.id"), primary_key=True),
 )
 
 
@@ -35,7 +35,7 @@ class Chemical(Base):
     __tablename__ = "aop_chemical"
 
     id = Column(Integer, primary_key=True)
-    aop_id = Column(String(45), index=True)
+    aop_hash = Column(String(45), index=True)
     casrn = Column(String(45), index=True)
     jchem_inchi_key = Column(String(255))
     indigo_inchi_key = Column(String(255))
@@ -43,7 +43,9 @@ class Chemical(Base):
     dsstox_id = Column(String(45))
 
     synonyms = relationship("Synonym", back_populates="chemical")
-    stressors = relationship("Stressor", secondary=stressor_chemical, back_populates="chemicals")
+    stressors = relationship(
+        "Stressor", secondary=stressor_chemical, back_populates="chemicals"
+    )
 
 
 class Stressor(Base):
@@ -52,14 +54,17 @@ class Stressor(Base):
     __tablename__ = "aop_stressor"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(String(45), index=True)
+    aop_id = Column(Integer, index=True)
+    aop_hash = Column(String(45), index=True)
     name = Column(String(255), index=True)
     description = Column(TEXT)
     exposure_characterization = Column(TEXT)
     creation = Column(DateTime)
     last_modified = Column(DateTime)
 
-    chemicals = relationship("Chemical", secondary=stressor_chemical, back_populates="stressors")
+    chemicals = relationship(
+        "Chemical", secondary=stressor_chemical, back_populates="stressors"
+    )
     aops = relationship("AopStressor", back_populates="stressor")
 
 
@@ -132,7 +137,7 @@ class Taxonomy(Base):
     __tablename__ = "aop_taxonomy"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(String(45), index=True)
+    aop_hash = Column(String(45), index=True)
     source = Column(String(45))
     source_id = Column(String(45))
     tax_id = Column(Integer, index=True)
@@ -151,7 +156,7 @@ class BiologicalObject(Base):
     __tablename__ = "aop_bio_object"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(String(45), index=True)
+    aop_hash = Column(String(45), index=True)
     source = Column(String(45))
     source_id = Column(String(45), index=True)
     name = Column(String(255))
@@ -165,7 +170,7 @@ class BiologicalProcess(Base):
     __tablename__ = "aop_bio_process"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(String(45), index=True)
+    aop_hash = Column(String(45), index=True)
     source = Column(String(45))
     source_id = Column(String(45), index=True)
     name = Column(String(255))
@@ -179,7 +184,7 @@ class BiologicalAction(Base):
     __tablename__ = "aop_bio_action"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(String(45), index=True)
+    aop_hash = Column(String(45), index=True)
     source = Column(String(45))
     source_id = Column(String(45), index=True)
     name = Column(String(255))
@@ -198,9 +203,15 @@ class BiologicalEvent(Base):
     bio_process_id = Column(Integer, ForeignKey(BiologicalProcess.id))
     bio_object_id = Column(Integer, ForeignKey(BiologicalObject.id))
 
-    bio_action = relationship("BiologicalAction", backref="events", foreign_keys=[bio_action_id])
-    bio_process = relationship("BiologicalProcess", backref="events", foreign_keys=[bio_process_id])
-    bio_object = relationship("BiologicalObject", backref="events", foreign_keys=[bio_object_id])
+    bio_action = relationship(
+        "BiologicalAction", backref="events", foreign_keys=[bio_action_id]
+    )
+    bio_process = relationship(
+        "BiologicalProcess", backref="events", foreign_keys=[bio_process_id]
+    )
+    bio_object = relationship(
+        "BiologicalObject", backref="events", foreign_keys=[bio_object_id]
+    )
 
     key_events = relationship("KeyEvent", secondary=ke_be, backref="bio_events")
 
@@ -211,7 +222,8 @@ class KeyEvent(Base):
     __tablename__ = "aop_key_event"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(String(45), index=True)
+    aop_id = Column(Integer, index=True)
+    aop_hash = Column(String(45), index=True)
     title = Column(String(255))
     source = Column(String(45))
     short_name = Column(String(255))
@@ -222,14 +234,20 @@ class KeyEvent(Base):
     evidence_supporting_taxonomic_applicability = Column(TEXT)
 
     # TODO: Add evidence and description metatable for stressor/KE
-    stressors = relationship("Stressor", secondary=stressor_ke, backref="key_events")  # many-to-many
+    stressors = relationship(
+        "Stressor", secondary=stressor_ke, backref="key_events"
+    )  # many-to-many
 
     # New tables for cell_term and organ_term - many-to-one
     organ_term_id = Column(Integer, ForeignKey(OrganTerm.id))
-    organ_term = relationship("OrganTerm", backref="key_events", foreign_keys=[organ_term_id])
+    organ_term = relationship(
+        "OrganTerm", backref="key_events", foreign_keys=[organ_term_id]
+    )
 
     cell_term_id = Column(Integer, ForeignKey(CellTerm.id))
-    cell_term = relationship("CellTerm", backref="key_events", foreign_keys=[cell_term_id])
+    cell_term = relationship(
+        "CellTerm", backref="key_events", foreign_keys=[cell_term_id]
+    )
 
     # Many to many rels
     sexes = relationship("SexKeyEvent", back_populates="key_event")
@@ -256,7 +274,7 @@ class KeyEventRelationship(Base):
     __tablename__ = "aop_key_event_relationship"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(String(45), index=True)
+    aop_hash = Column(String(45), index=True)
     description = Column(TEXT)
     quantitative_understanding = Column(TEXT)
     evidence_supporting_taxonomic_applicability = Column(TEXT)
@@ -270,7 +288,9 @@ class KeyEventRelationship(Base):
     down_event_id = Column(Integer, ForeignKey(KeyEvent.id))
 
     up_event = relationship("KeyEvent", backref="up_events", foreign_keys=[up_event_id])
-    down_event = relationship("KeyEvent", backref="down_events", foreign_keys=[down_event_id])
+    down_event = relationship(
+        "KeyEvent", backref="down_events", foreign_keys=[down_event_id]
+    )
 
     # Evidence columns
     evidence_value = Column(TEXT)
@@ -296,7 +316,8 @@ class Aop(Base):
     __tablename__ = "aop"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(String(45), index=True)
+    aop_id = Column(Integer, index=True)
+    aop_hash = Column(String(45), index=True)
     title = Column(String(255))
     background = Column(TEXT)
     short_name = Column(String(255))
@@ -428,7 +449,7 @@ class SexAop(Base):
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     sex_id = Column(Integer, ForeignKey(Sex.id), index=True)
-    aop_id = Column(Integer, ForeignKey(Aop.id), index=True)
+    aop_hash = Column(Integer, ForeignKey(Aop.id), index=True)
     evidence = Column(TEXT)
 
     sex = relationship(Sex, back_populates="aops")
@@ -442,7 +463,7 @@ class LifeStageAop(Base):
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     life_stage_id = Column(Integer, ForeignKey(LifeStage.id), index=True)
-    aop_id = Column(Integer, ForeignKey(Aop.id), index=True)
+    aop_hash = Column(Integer, ForeignKey(Aop.id), index=True)
     evidence = Column(TEXT)
 
     life_stage = relationship(LifeStage, back_populates="aops")
@@ -456,7 +477,7 @@ class TaxonomyAop(Base):
 
     id = Column(Integer, primary_key=True, autoincrement=True)
     tax_id = Column(Integer, ForeignKey(Taxonomy.id), index=True)
-    aop_id = Column(Integer, ForeignKey(Aop.id), index=True)
+    aop_hash = Column(Integer, ForeignKey(Aop.id), index=True)
     evidence = Column(TEXT)
 
     taxonomy = relationship(Taxonomy, back_populates="aops")
@@ -469,7 +490,7 @@ class AopKer(Base):
     __tablename__ = "aop_kers_aop_association"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(Integer, ForeignKey(Aop.id), index=True)
+    aop_hash = Column(Integer, ForeignKey(Aop.id), index=True)
     ker_id = Column(Integer, ForeignKey(KeyEventRelationship.id), index=True)
     adjacency = Column(String(45))
     quantitative_understanding_value = Column(String(45))
@@ -485,7 +506,7 @@ class AopKeyEvent(Base):
     __tablename__ = "aop_key_event_aop_association"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(Integer, ForeignKey(Aop.id), index=True)
+    aop_hash = Column(Integer, ForeignKey(Aop.id), index=True)
     key_event_id = Column(Integer, ForeignKey(KeyEvent.id), index=True)
     evidence = Column(TEXT)
     key_event_type = Column(String(45))
@@ -500,7 +521,7 @@ class AopStressor(Base):
     __tablename__ = "aop_stressor_aop_association"
 
     id = Column(Integer, primary_key=True, autoincrement=True)
-    aop_id = Column(Integer, ForeignKey(Aop.id), index=True)
+    aop_hash = Column(Integer, ForeignKey(Aop.id), index=True)
     stressor_id = Column(Integer, ForeignKey(Stressor.id), index=True)
     description = Column(TEXT)
     evidence = Column(String(45))
